@@ -15,9 +15,9 @@
  *
  *-------------------------------------------------------------------------
  */
-#include "pqxx/tablereader.h"
-#include "pqxx/tablewriter.h"
-#include "pqxx/transaction.h"
+#include "pqxx/tablereader"
+#include "pqxx/tablewriter"
+#include "pqxx/transaction"
 
 using namespace PGSTD;
 
@@ -37,7 +37,7 @@ pqxx::tablewriter::~tablewriter()
   }
   catch (const exception &e)
   {
-    Trans().ProcessNotice(e.what());
+    Trans().process_notice(e.what());
   }
 }
 
@@ -45,7 +45,7 @@ pqxx::tablewriter::~tablewriter()
 pqxx::tablewriter &pqxx::tablewriter::operator<<(pqxx::tablereader &R)
 {
   string Line;
-  while (R.GetRawLine(Line))
+  while (R.get_raw_line(Line))
     WriteRawLine(Line);
 
   return *this;
